#
# Makefile Template for Tessy
#
# Compiler: Tasking/Tricore VX 3.x
# Debugger: UDE
# Template Version : 2
#

# Defines to be generated by Tessy:
#
# BUFFER_SIZE           :=
# COMPILER_DEFINES      :=
# COMPILER_INCLUDES     :=
# COMPILER_INSTALL_PATH :=
# ENDIANESS             :=
# EXEFILE_EXTENSION     :=
# LIBRARY               :=
# LINKER_FILE           :=
# MODULE_PATH           :=
# MODULE_PATH_DOS       :=
# OBJFILE_EXTENSION     :=
# PROJECTROOT           :=
# TARGET_INSTALL_PATH   :=
# TESSY_BIN             :=
# TESSY_SYS             :=
# TESTOBJECT            :=
# USER_LINK_OPTIONS     :=

#####################################################################
#BEGIN_DEFINES
#####################################################################

#
# Special macros for includes and defines
#
TS_DEF_SEPARATOR :=-D
define TS_DEFINE
$(subst ;, $(TS_DEF_SEPARATOR),$(1))
endef

TS_INC_SEPARATOR :=-I
define TS_INCLUDE
$(subst ;, $(TS_INC_SEPARATOR),$(1))
endef

TESSY_SYS_DOS   := $(shell ts_pathname -s '$(TESSY_SYS)')
MODULE_PATH_DOS := $(shell ts_pathname -s '$(MODULE_PATH)')
TASKING_HOME    := $(shell ts_pathname -s '$(COMPILER_INSTALL_PATH)')

TS_NAME         := TS_TASKING_VX
IDE_NAME        := ude
COMPANY_NAME    := taskingvx
PROCESSOR_NAME  := tricore
TS_BYTEORDER    := TS_HOST_BYTEORDER

ifeq ("little","$(ENDIANESS)")
  TS_BYTEORDER := TS_HOST_BYTEORDER
endif
ifeq ("big","$(ENDIANESS)")
  TS_BYTEORDER := TS_NET_BYTEORDER
endif
ifndef TS_BYTEORDER
  $(error Attribute 'Endianess' has invalid value '$(ENDIANESS)', only 'little' and 'big' are allowed.)
endif

all	 : master slave

#
# MASTER & COMM Makefiles
# (you should not need to modify these settings)
#
M_COMM_MAKE    := $(TESSY_SYS)/make/master_$(IDE_NAME)_gnu_i386.mk
S_COMM_MAKE    := $(TESSY_SYS)/src/comm/comm_$(IDE_NAME)_$(COMPANY_NAME)_$(PROCESSOR_NAME).mk


#
#
# SLAVE
#

S_CC           := $(shell ts_pathname -s '$(TASKING_HOME)')\bin\cctc.exe
S_ASM          := $(shell ts_pathname -s '$(TASKING_HOME)')\bin\cctc.exe
S_LINK         := $(shell ts_pathname -s '$(TASKING_HOME)')\bin\cctc.exe
S_INCLUDES     := -I"$(TESSY_SYS_DOS)\include\tessy\comm" -I"$(MODULE_PATH_DOS)" -I"$(TASKING_HOME)\include"
S_STUB_OBJECT  := $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_stubs$(OBJFILE_EXTENSION)
S_UC_OBJECT    := $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_usr$(OBJFILE_EXTENSION)


# Options to be copied from the Tasking EDE generated makefile
#
# CPU = "TC1797"
TASKING_EDE_OPT_CC  := -C"$(CPU)" -t -Wa-gAHLs --emit-locals=-equ,-symbols -Wa-Ogs \
                       -Wa--error-limit=42 --iso=99 --language=-gcc,-volatile,+strings \
                       --switch=auto --align=0 --default-near-size=0 --default-a0-size=0 \
                       --default-a1-size=0 -O2 --tradeoff=4 --compact-max-size=200 -g --source \
                       --use-double-precision-fp

TASKING_EDE_OPT_ASM := -C"$(CPU)" -t -Wa-gAHLs --emit-locals=-equ,-symbols -Wa-Ogs -Wa--error-limit=42

TASKING_EDE_OPT_LC  := -C"$(CPU)" -t "$(LINKER_FILE)" -Wl-OtxycL --no-map-file \
                       -Wl--map-file="$(MODULE_PATH_DOS)\ts_$(TESTOBJECT).mapxml":XML \
							  -Wl-mcrfiklSmNOduQ -Wl--error-limit=42 -g

#
#
S_COMP_OPTIONS := $(TASKING_EDE_OPT_CC) -e -w -DTESSY -DTS_SLAVE -D$(TS_NAME) -DTS_TRICORE -DTS_HAVE_FLOAT \
						-DTS_HAVE_FLOAT64	-DTS_HAVE_INT64

S_LINK_OPTIONS	:= $(TASKING_EDE_OPT_LC) $(LIBRARIES) -L"$(TASKING_HOME)\lib\tc13"

#####################################################################
#END_DEFINES
#####################################################################

#####################################################################
#BEGIN_SOURCE
#####################################################################

#
# Template rules
#
$(MODULE_PATH_DOS)\ts_src$$(SOURCENUMBER)$(OBJFILE_EXTENSION): $(MODULE_PATH_DOS)\ts_src$$(SOURCENUMBER).c
	$(S_CC) $(S_INCLUDES) $(call TS_INCLUDE,$(USER_INCLUDES$$(SOURCENUMBER))) $(S_COMP_OPTIONS) \
		$(call TS_DEFINE,$(USER_DEFINES$$(SOURCENUMBER))$(S_COM_OPTIONS)) \
		$(USER_COMP_OPTIONS$$(SOURCENUMBER)) -o $@ -c $<


#####################################################################
#END_SOURCE
#####################################################################

#####################################################################
#BEGIN_TARGETS
#####################################################################

master : $(MODULE_PATH)/ts_$(TESTOBJECT)_m.exe
slave  : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(EXEFILE_EXTENSION)

# COMPILE USERCODE / STUBS
#
$(S_UC_OBJECT) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_usr.c
	@echo ***** Compiling Usercode *****
	$(S_CC) $(S_INCLUDES) $(S_COMP_OPTIONS) -I$(MODULE_PATH_DOS) -c $< -o $@

$(S_STUB_OBJECT) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_stubs.c
	@echo ***** Compiling Stubs *****
	$(S_CC) $(S_INCLUDES) $(S_COMP_OPTIONS) -I$(MODULE_PATH_DOS) -c $< -o $@


#
# COMPILE/LINK MASTER
#

include $(M_COMM_MAKE)


#
# COMPILE SLAVE COMMUNICATION MODULES

include $(S_COMM_MAKE)



#
#
# COMPILE/LINK SLAVE
#
$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.c
	@echo *
	@echo ***** Compiling Slave *****
	$(S_CC) $(S_COMP_OPTIONS) $(S_INCLUDES) -I$(MODULE_PATH_DOS) -c $< -o $@

$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(EXEFILE_EXTENSION) : $(STARTUP_FILE) $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) \
															$(S_SRC_OBJECTS) \
															$(S_UC_OBJECT) \
															$(S_STUB_OBJECT) \
															$(S_OBJECTS)
	@echo *
	@echo ***** Linking Slave *****
	$(S_LINK) $(S_LINK_OPTIONS) -o $@ $(USER_LINK_OPTIONS) $(STARTUP_FILE) \
					$(S_OBJECTS) $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) \
					$(S_SRC_OBJECTS) $(S_UC_OBJECT) $(S_STUB_OBJECT)


#####################################################################
#END_TARGETS
#####################################################################

